@@ -1,7 +1,7 @@
 """Run the generation process"""
 
 import os.path
-import sys
+import re
 import textwrap
 from typing import Any, Optional
 
@@ -40,23 +40,31 @@ def wrap(text: str, cols: int) -> str:
         res += textwrap.wrap(each, width=cols, break_long_words=False) or ['']
     return '\\n'.join(res)
 
+
 class Generator:
+    RX_NUMBERED_NAME = re.compile(r'(\d+[.])(.*)')
+
     def __init__(self, graph_options: model.GraphOptions) -> None:
         self.lines: list[str] = []
         self.star_nr = 0
         self.frame_nr = 0
         self.graph_options = graph_options
 
-    def append(self, line:str, statement: model.Statement) -> None:
+    def append(self, line: str, statement: model.Statement) -> None:
         self.lines.append('')
         text = model.pack(statement.source.text)
         self.lines.append(f'/* {statement.source.line_nr}: {text} */')
         self.lines.append(line)
 
     def generate_item(self, item: model.Item) -> None:
-        text = wrap(item.text, self.graph_options.item_text_width)
-        attrs = item.attrs or ''
-        match item.type:
+        copy = model.Item(**item.__dict__)
+        hits = self.RX_NUMBERED_NAME.findall(copy.text)
+        if hits:
+            copy.text = '\\n'.join(hits[0])
+
+        copy.text = wrap(copy.text, self.graph_options.item_text_width)
+        attrs = copy.attrs or ''
+        match copy.type:
             case model.PROCESS:
                 if self.graph_options.is_context:
                     shape = 'circle'
@@ -64,30 +72,30 @@ class Generator:
                 else:
                     shape = 'ellipse'
                     fc = '"#eeeeee"'
-                line = (f'"{item.name}" [shape={shape} label="{text}" '
+                line = (f'"{copy.name}" [shape={shape} label="{copy.text}" '
                         f'fillcolor={fc} style=filled {attrs}]')
             case model.CONTROL:
                 fc = '"#eeeeee"'
-                line = (f'"{item.name}" [shape=ellipse label="{text}" '
+                line = (f'"{copy.name}" [shape=ellipse label="{copy.text}" '
                         f'fillcolor={fc} style="filled,dashed" {attrs}]')
             case model.ENTITY:
-                line = (f'"{item.name}" [shape=rectangle label="{text}" '
+                line = (f'"{copy.name}" [shape=rectangle label="{copy.text}" '
                         f'{attrs}]')
             case model.STORE:
-                d = self._item_to_html_dict(item)
+                d = self._item_to_html_dict(copy)
                 line = TMPL.STORE.format(**d)
             case model.NONE:
-                line = f'"{item.name}" [shape=none label="{text}" {attrs}]'
+                line = f'"{copy.name}" [shape=none label="{copy.text}" {attrs}]'
             case model.CHANNEL:
-                d = self._item_to_html_dict(item)
+                d = self._item_to_html_dict(copy)
                 if self.graph_options.is_vertical:
                     line = TMPL.CHANNEL_HORIZONTAL.format(**d)
                 else:
                     line = TMPL.CHANNEL.format(**d)
             case _:
-                prefix = model.mk_err_prefix_from(item.source)
+                prefix = model.mk_err_prefix_from(copy.source)
                 raise model.DfdException(f'{prefix}Unsupported item type '
-                                         f'"{item.type}"')
+                                         f'"{copy.type}"')
         self.append(line, item)
 
     def _item_to_html_dict(self, item: model.Item) -> dict[str, Any]:
@@ -127,7 +135,8 @@ class Generator:
                 dst_port = ':x:c'
 
         attrs = f'label="{text}"'
-        if conn.attrs: attrs += ' ' + conn.attrs
+        if conn.attrs:
+            attrs += ' ' + conn.attrs
 
         match conn.type:
             case model.FLOW:
@@ -191,7 +200,7 @@ class Generator:
             block=block,
             graph_params='\n  '.join(graph_params),
         ).replace('\n  \n', '\n\n')
-        #print(text)
+        # print(text)
         return text
 
 
